# -*- coding: utf-8 -*-
from plone.gallery.testing import PLONE_GALLERY_FUNCTIONAL_TESTING
from plone.gallery.testing import PLONE_GALLERY_INTEGRATION_TESTING
from plone import api
from plone.app.testing import setRoles
from plone.app.testing import TEST_USER_ID
from zope.component import getMultiAdapter
from zope.component.interfaces import ComponentLookupError

import unittest


class ViewsIntegrationTest(unittest.TestCase):

    layer = PLONE_GALLERY_INTEGRATION_TESTING

    def setUp(self):
        self.portal = self.layer['portal']
        setRoles(self.portal, TEST_USER_ID, ['Manager'])
        api.content.create(self.portal, 'Folder', 'other-folder')
        api.content.create(self.portal, 'Document', 'front-page')

    def test_photo_gallery_is_registered(self):
        view = getMultiAdapter(
            (self.portal['other-folder'], self.portal.REQUEST),
            name='photo-gallery'
        )
        self.assertTrue(view.__name__ == 'photo-gallery')
        # self.assertTrue(
        #     'Sample View' in view(),
        #     'Sample View is not found in photo-gallery'
        # )

    def test_photo_gallery_not_matching_interface(self):
        with self.assertRaises(ComponentLookupError):
            getMultiAdapter(
                (self.portal['front-page'], self.portal.REQUEST),
                name='photo-gallery'
            )


class ViewsFunctionalTest(unittest.TestCase):

    layer = PLONE_GALLERY_FUNCTIONAL_TESTING

    def setUp(self):
        self.portal = self.layer['portal']
        setRoles(self.portal, TEST_USER_ID, ['Manager'])



# -*- coding: utf-8 -*-
"""Module where all interfaces, events and exceptions live."""

from zope.publisher.interfaces.browser import IDefaultBrowserLayer


class IPloneGalleryLayer(IDefaultBrowserLayer):
    """Marker interface that defines a browser layer."""



# -*- coding: utf-8 -*-

# from plone.gallery import _
from plone.app.contenttypes.browser.folder import FolderView
from plone.app.contenttypes.browser.collection import CollectionView
from Products.CMFPlone.resources import add_bundle_on_request


class PhotoGallery(FolderView):

    def __call__(self):
        add_bundle_on_request(self.request, "spotlightjs")
        add_bundle_on_request(self.request, "flexbin")
        return self.index()

    # We need to get the scale url here, without the tag.
    # right now we use the old way with the scale name in the url for the big picture

    # def images_view(self):
    #     return

    # def scale(
    #         self,
    #         brain,
    #         fieldname=None,
    #         scale=None,
    #         height=None,
    #        # def images_view(self):
    #     return

    # def scale(
    #         self,
    #         brain,
    #         fieldname=None,
    #         scale=None,
    #         height=None,
    #         width=None,
    #         direction='thumbnail',
    #         **kwargs):
    #     obj = brain.getObject()
    #     images = obj.restrictedTraverse('@@images')
    #     tag = images.tag(fieldname, **kwargs)
    #     return tag     **kwargs):
    #     obj = brain.getObject()
    #     images = obj.restrictedTraverse('@@images')
    #     tag = images.tag(fieldname, **kwargs)
    #     return tag


class PhotoGalleryCollection(CollectionView):

    def __call__(self):
        add_bundle_on_request(self.request, "spotlightjs")
        add_bundle_on_request(self.request, "flexbin")
        return self.index()
